@@ -316,7 +316,8 @@ class BaseExperiment:
         return self.model
 
     def get_data_module(
-        self
+        self,
+        stratify : bool = True
     )->Union["pl.LightningDataModule", Tuple["np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray"]]:
         r"""Method for getting a datamodule.
 
@@ -331,6 +332,9 @@ class BaseExperiment:
         del self.data_module
         self.data_module = None
         data_module = None
+        if self.n_classes is None and stratify:
+            logger.info(f"Unable to stratify continuous targets. Will split the data without label stratification.")
+            stratify = False
         if isinstance(self.model, ConvNet) or isinstance(self.model, SegNet):
             if len(self.X.shape) > 2:
                 data_module = initialize_datamodule(
@@ -342,7 +346,8 @@ class BaseExperiment:
                     X_test=self.X_test,
                     y_test=self.y_test,
                     test_size=self.test_size,
-                    random_state=self.random_state
+                    random_state=self.random_state,
+                    stratify=stratify
                 )
             else: 
                 raise AssertionError("Wrong dimension for vision data. You must specify the dimensions of the data, not in a flattened way.")
@@ -357,7 +362,8 @@ class BaseExperiment:
                     X_test=self.X_test.reshape((self.X_test.shape[0], -1)),
                     y_test=self.y_test,
                     test_size=self.test_size,
-                    random_state=self.random_state
+                    random_state=self.random_state,
+                    stratify=stratify
                 )
             
             if self.X_val is not None and self.y_val is not None and self.X_test is None and self.y_test is None:
@@ -370,7 +376,8 @@ class BaseExperiment:
                     X_test=self.X_test,
                     y_test=self.y_test,
                     test_size=self.test_size,
-                    random_state=self.random_state
+                    random_state=self.random_state,
+                    stratify=stratify
                 )
             
             if self.X_val is None and self.y_val is None and self.X_test is not None and self.y_test is not None:
@@ -383,7 +390,8 @@ class BaseExperiment:
                     X_test=self.X_test.reshape((self.X_test.shape[0], -1)),
                     y_test=self.y_test,
                     test_size=self.test_size,
-                    random_state=self.random_state
+                    random_state=self.random_state,
+                    stratify=stratify
                 )
             if self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
                 data_module = initialize_datamodule(
@@ -395,7 +403,8 @@ class BaseExperiment:
                     X_test=self.X_test,
                     y_test=self.y_test,
                     test_size=self.test_size,
-                    random_state=self.random_state
+                    random_state=self.random_state,
+                    stratify=stratify
                 )
 
         elif isinstance(self.model, pl.LightningModule): # other lightning modules not in astrape
@@ -410,7 +419,8 @@ class BaseExperiment:
                     X_test=self.X_test,
                     y_test=self.y_test,
                     test_size=self.test_size,
-                    random_state=self.random_state
+                    random_state=self.random_state,
+                    stratify=stratify
                 )
             elif self.X_val is not None and self.y_val is not None and self.X_test is None and self.y_test is None:
                 data_module = initialize_datamodule(
@@ -422,7 +432,8 @@ class BaseExperiment:
                     X_test=self.X_test,
                     y_test=self.y_test,
                     test_size=self.test_size,
-                    random_state=self.random_state
+                    random_state=self.random_state,
+                    stratify=stratify
                 )
             
             elif self.X_val is None and self.y_val is None and self.X_test is not None and self.y_test is not None:
@@ -435,7 +446,8 @@ class BaseExperiment:
                     X_test=self.X_test.reshape((self.X_test.shape[0], -1)),
                     y_test=self.y_test,
                     test_size=self.test_size,
-                    random_state=self.random_state
+                    random_state=self.random_state,
+                    stratify=stratify
                 )
 
             elif self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
@@ -448,17 +460,29 @@ class BaseExperiment:
                     X_test=self.X_test,
                     y_test=self.y_test,
                     test_size=self.test_size,
-                    random_state=self.random_state
+                    random_state=self.random_state,
+                    stratify=stratify
                 )
         elif isinstance(self.model, BaseEstimator):
-            if self.X_test is None and self.y_test is None:  
-                X_, X_test, y_, y_test = train_test_split(self.X, self.y, test_size=self.test_size, stratify=self.y)
-                X_train, X_val, y_train, y_val = train_test_split(X_, y_, test_size=self.test_size, stratify=y_)
+            if self.X_test is None and self.y_test is None:
+                if self.n_classes is None:
+                    if stratify:
+                        logger.info(f"Unable to stratify continuous targets. Will split the data without label stratification.")
+                        stratify = False
+                    X_, X_test, y_, y_test = train_test_split(self.X, self.y, test_size=self.test_size)
+                    X_train, X_val, y_train, y_val = train_test_split(X_, y_, test_size=self.test_size)
+                else:
+                    X_, X_test, y_, y_test = train_test_split(self.X, self.y, test_size=self.test_size, stratify=self.y)
+                    X_train, X_val, y_train, y_val = train_test_split(X_, y_, test_size=self.test_size, stratify=y_)
+                
                 self.X_train, self.X_val, self.X_test = X_train, X_val, X_test
                 self.y_train, self.y_val, self.y_test = y_train, y_val, y_test
                 data_module = (X_train, X_val, y_train, y_val, X_test, y_test)
             elif self.X_test is not None and self.y_test is not None:
-                X_train, X_val, y_train, y_val = train_test_split(self.X, self.y, test_size=self.test_size, stratify=self.y)
+                if self.n_classes is None:
+                    X_train, X_val, y_train, y_val = train_test_split(self.X, self.y, test_size=self.test_size)
+                else:
+                    X_train, X_val, y_train, y_val = train_test_split(self.X, self.y, test_size=self.test_size, stratify=self.y)
                 data_module = (X_train, X_val, y_train, y_val, X_test, y_test)
                 self.X_train, self.X_val = X_train, X_val
                 self.y_train, self.y_val = y_train, y_val
@@ -816,7 +840,10 @@ class BaseExperiment:
         model_type : "pl.LightningModule",
         **hparams
     ):
-        pseudomodel = model_type(**hparams)
+        if BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type):
+            pseudomodel = model_type(dims=self.dims, n_classes=self.n_classes, **hparams)
+        else:
+            pseudomodel = model_type(**hparams)
         model_metadata = self.set_model_metadata(pseudomodel, hparams)
         ckpt_dir = f'{self.log_path}/checkpoints/{model_type.__name__}/{model_metadata}' 
         jsonlog_dir = f'{self.log_path}/jsonlogs/{model_type.__name__}/{model_metadata}' 
