@@ -25,7 +25,7 @@ import matplotlib.colors as mcolors
 from sklearn.decomposition import PCA
 import logging
 from itertools import product
-
+import shutil
 from astrape.utilities.utils import rearrange_dims
 log = logging.getLogger(__name__)
 
@@ -164,6 +164,22 @@ class BaseProject:
         with open(json_name, 'w') as fout:
             json.dump(self.project_metadata, fout)
     
+    def delete_empty_exps(
+        self
+    )->None:
+        r"""Delete empty experiments (if any). 
+        This will delete empty {path}/{project_name}/FIT/random_state_{random_state} folder.
+        """
+        path = f"{self.path}/{self.project_name}/FIT"
+        for exp in os.listdir(path):
+            if len(exp) == 0:
+                log.info(f"logs folder has not been created in {exp}. Deleting {exp}...")
+                shutil.rmtree(f"{path}/{exp}")
+            jsonlog_path = f"{path}/{exp}/logs/jsonlogs"
+            if len(os.listdir(jsonlog_path)) == 0:
+                log.info(f"{exp} is an empty experiment. Deleting {exp}...")
+                shutil.rmtree(f"{path}/{exp}")  
+
     def create_experiments(
         self,
         amount : int = 10,
@@ -713,7 +729,13 @@ class BaseProject:
         mode = 'min' if val_metric == 'val/loss' else 'max'
         random_state_dir_list = self.get_available_random_states()
         for random_state_dir in random_state_dir_list:
+            if len(os.listdir(random_state_dir)) == 0:
+                continue
+            if len(os.listdir(f"{random_state_dir}/logs")) == 0:
+                continue
             jsonlog_dir = f"{random_state_dir}/logs/jsonlogs"
+            if len(os.listdir(f"{jsonlog_dir}")) == 0:
+                continue
             for model_type_dir in os.listdir(jsonlog_dir): 
                 for metadata_dir in os.listdir(f'{jsonlog_dir}/{model_type_dir}'): 
                     for version in os.listdir(f'{jsonlog_dir}/{model_type_dir}/{metadata_dir}'): 
@@ -778,7 +800,13 @@ class BaseProject:
         mode = 'min' if val_metric == 'val/loss' else 'max'
         random_state_dir_list = self.get_available_random_states()
         for random_state_dir in random_state_dir_list:
-            jsonlog_dir = f'{random_state_dir}/logs/jsonlogs'
+            if len(os.listdir(random_state_dir)) == 0:
+                continue
+            if len(os.listdir(f"{random_state_dir}/logs")) == 0:
+                continue
+            jsonlog_dir = f"{random_state_dir}/logs/jsonlogs"
+            if len(os.listdir(f"{jsonlog_dir}")) == 0:
+                continue
             for model_type_dir in os.listdir(jsonlog_dir): 
                 if str(model_type_dir) == model_type.__name__:
                     for metadata_dir in os.listdir(f'{jsonlog_dir}/{model_type_dir}'): 
@@ -845,7 +873,13 @@ class BaseProject:
         mode = 'min' if val_metric == 'val/loss' else 'max'
         random_state_dir_list = self.get_available_random_states()
         for random_state_dir in random_state_dir_list:
+            if len(os.listdir(random_state_dir)) == 0:
+                continue
+            if len(os.listdir(f"{random_state_dir}/logs")) == 0:
+                continue
             jsonlog_dir = f"{random_state_dir}/logs/jsonlogs"
+            if len(os.listdir(f"{jsonlog_dir}")) == 0:
+                continue
             for model_type_dir in os.listdir(jsonlog_dir):
                 for metadata_dir in os.listdir(f"{jsonlog_dir}/{model_type_dir}"):
                     if str(metadata_dir) == metadata: 
@@ -897,7 +931,13 @@ class BaseProject:
 
         performances_per_metadata = {}
         for random_state_dir in random_state_dir_list:
-            jsonlog_dir = f'{random_state_dir}/logs/jsonlogs'
+            if len(os.listdir(random_state_dir)) == 0:
+                continue
+            if len(os.listdir(f"{random_state_dir}/logs")) == 0:
+                continue
+            jsonlog_dir = f"{random_state_dir}/logs/jsonlogs"
+            if len(os.listdir(f"{jsonlog_dir}")) == 0:
+                continue
             for model_type_dir in os.listdir(jsonlog_dir): 
                 for metadata_dir in os.listdir(f'{jsonlog_dir}/{model_type_dir}'):
                     if metadata_dir not in metadata_list:
@@ -1071,7 +1111,7 @@ class Project(BaseProject):
                 plt_title = 'Best Performance for Each Random State'
             plt.title(plt_title)
             plt.ylim = (ymin, ymax)
-            self._create_folder(self.project_path+"/results")
+            self._create_folder(f"{self.project_path}/results")
             plt.show()
             file_name = plt_title.replace(" ", "-")
             plt.savefig(self.project_path+f"/results/{file_name}.png")
@@ -1157,6 +1197,7 @@ class Project(BaseProject):
         Returns:
 
             tuple: (numpy ndarray of validation performances, list of random states of saved ``Experiments``, dictionary containing information of the search)
+            
         """
         if self.n_classes is None and val_metric != "val/loss": # regression
             raise AssertionError(f"{val_metric} is not a valid metric for regression tasks.")
@@ -1374,7 +1415,4 @@ class Project(BaseProject):
         plt.savefig(self.project_path+f"/results/{file_name}_boxplot.png")
         self.project_logger.add_figure(f'results/{plt_title}_boxplot', fig2)
 
-        return (performances_list, metadata_list)
-
-    
-
+        return (performances_list, metadata_list)
\ No newline at end of file
