@@ -14,7 +14,8 @@ def split_data(
         test_size : float = 0.1,
         X_test : Optional[Union["torch.Tensor", "np.ndarray", "pd.DataFrame"]] = None,
         y_test : Optional[Union["torch.Tensor", "np.ndarray", "pd.DataFrame"]] = None,
-        random_state : int = 0
+        random_state : int = 0,
+        stratify : bool = True
 ):
     r"""
     Args:
@@ -37,7 +38,16 @@ def split_data(
         raise ValueError("X_test and y_test should both be specified as a certain np.array object, or else all be NoneType objects.")
 
     elif X_test is None and y_test is None:
-        X_train, X_test, y_train, y_test = train_test_split(
+        if stratify:
+            X_train, X_test, y_train, y_test = train_test_split(
+                    X,
+                    y, 
+                    test_size=test_size, 
+                    random_state=random_state,
+                    stratify=y
+                ) 
+        else:
+            X_train, X_test, y_train, y_test = train_test_split(
                 X,
                 y, 
                 test_size=test_size, 
@@ -52,13 +62,19 @@ def split_data(
     X_test_tensor = torch.Tensor(X_test).float() if not isinstance(X_test, torch.Tensor) else X_test.float()
     y_test_tensor = torch.Tensor(y_test).float() if not isinstance(y_test, torch.Tensor) else y_test.float()
 
-   
-    X_train, X_val, y_train, y_val = train_test_split(
-        X_train,
-        y_train,
-        random_state=0
-    )
-    
+    if stratify:
+        X_train, X_val, y_train, y_val = train_test_split(
+            X_train,
+            y_train,
+            random_state=0,
+            stratify=y_train
+        )
+    else:
+        X_train, X_val, y_train, y_val = train_test_split(
+            X_train,
+            y_train,
+            random_state=0
+        )
     
     X_train_tensor = torch.Tensor(X_train).float() if not isinstance(X_train, torch.Tensor) else X_train.float()
     y_train_tensor = torch.Tensor(y_train).float() if not isinstance(y_train, torch.Tensor) else y_train.float()
